﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Tempesta.Web.Syndication
{
	/// <summary>
	/// The PICS rating for the channel.
	/// The channel's rating element supplies an advisory label for the content in a feed formatted according to the specification for the Platform for Internet Content Selection (PICS)
	/// http://www.w3.org/PICS
	/// </summary>
	public class PicsRating
	{
		private string _rating;

		/// <summary>
		/// Initializes a new instance of the <c>PicsRating</c> class with default properties.
		/// </summary>
		/// <exception cref="System.ArgumentNullException">If rating is null or empty.</exception>
		public PicsRating(string rating)
		{
			if (String.IsNullOrEmpty(rating))
			{
				throw new ArgumentNullException("rating");
			}

			_rating = rating;
		}

		/// <summary>
		/// Returns a string representation of the PICS rating.
		/// </summary>
		/// <returns>A string representation of the PICS rating.</returns>
		public override string ToString()
		{
			return _rating;
		}
	}
}
