﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Tempesta.Web.Syndication
{
	/// <summary>
	/// Specify one or more categories that the channel belongs to.
	/// </summary>
	public class RssCategory
	{
		/// <summary>
		/// The value of the element is a forward-slash-separated string that identifies a hierarchic location in the indicated taxonomy.
		/// </summary>
		public string Name { get; set; }

		/// <summary>
		/// A string that identifies a categorization taxonomy.
		/// </summary>
		public string Domain { get; set; }

		/// <summary>
		/// Represents the hierarchical slash-delimited category name as an array of strings, whose first item (index = 0) is the first value in the category name, followed by any other item according to their hierarchical position in the taxonomy.
		/// </summary>
		public string[] Taxonomy { get; private set; }

		/// <summary>
		/// Initializes a new instance of the <c>RssCategory</c> class with the value indicated in the input parameter.
		/// </summary>
		/// <param name="name">The name of the category.</param>
		public RssCategory(string name)
			: this(name, string.Empty)
		{
		}

		/// <summary>
		/// Initializes a new instance of the <c>RssCategory</c> class with the values indicated in the input parameters.
		/// </summary>
		/// <param name="name">The name of the category.</param>
		/// <param name="domain">The domain of the category. This parameter is optional, and if not provided, its value is defaulted to a blank string.</param>
		/// <exception cref="System.ArgumentNullException">If name is null or empty.</exception>
		public RssCategory(string name, string domain)
		{
			if (String.IsNullOrEmpty(name))
			{
				throw new ArgumentNullException("name");
			}
			if (domain == null)	// accept empty value
			{
				domain = string.Empty;
			}

			Name = name;
			Domain = domain;

			Taxonomy = Name.Split(new string[] { "/" }, StringSplitOptions.RemoveEmptyEntries);
		}
	}
}
