﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Tempesta.Web.Syndication
{
	/// <summary>
	/// An item's enclosure element associates a media object such as an audio or video file with the item.
	/// </summary>
	public class RssEnclosure
	{
		/// <summary>
		/// The file's MIME media type.
		/// </summary>
		public string MimeType { get; set; }

		/// <summary>
		/// The URL of the file.
		/// </summary>
		public Uri Url { get; set; }

		/// <summary>
		/// The size of the file in bytes.
		/// When the size of some media objects cannot be determined, for example for streaming media formats, the default value 0 (zero) should be used.
		/// </summary>
		public long Length { get; set; }

		/// <summary>
		/// Initializes a new instance of the <c>RssEnclosure</c> class with the values indicated in the input parameters and length = 0.
		/// </summary>
		/// <param name="mimeType">The MIME type of the media file.</param>
		/// <param name="url">The URL of the media file.</param>
		public RssEnclosure(string mimeType, Uri url)
			: this(mimeType, url, 0)
		{
		}

		/// <summary>
		/// Initializes a new instance of the <c>RssEnclosure</c> class with the values indicated in the input parameters.
		/// </summary>
		/// <param name="mimeType">The MIME type of the media file.</param>
		/// <param name="url">The URL of the media file.</param>
		/// <param name="length">The length in bytes of the media file.</param>
		/// <exception cref="System.ArgumentNullException">If mimeType is null or empty.</exception>
		/// <exception cref="System.ArgumentNullException">If url is null.</exception>
		public RssEnclosure(string mimeType, Uri url, long length)
		{
			if (String.IsNullOrEmpty(mimeType))
			{
				throw new ArgumentNullException("mimeType");
			}
			if (url == null)
			{
				throw new ArgumentNullException("url");
			}

			MimeType = mimeType;
			Url = url;
			Length = length;
		}
	}
}
